@@ -18,10 +18,23 @@ speakers of the various dialects of English. C<;-)>
 
 Philippe Bruhat
 
-Introduced in Acme-MetaSyntactic version 0.77, published on June 5, 2006.
+=head1 CHANGES
 
-Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
-published on May 7, 2012.
+=over 4
+
+=item *
+
+2012-05-07 - v1.000
+
+Received its own version number in Acme-MetaSyntactic-Themes version 1.000.
+
+=item *
+
+2005-06-05
+
+Introduced in Acme-MetaSyntactic version 0.77.
+
+=back
 
 =head1 SEE ALSO
 
